#ifndef _rechecks_h_
#define _rechecks_h_

#include <sys/types.h>
#include <regex.h>


class rechecks {

    public:

    	typedef enum {
    		FILE_PKG,
    		FILE_INDEX,
    		FILE_INVALID
    	} eFileKind;
    	
        rechecks();
        /* virtual, not needed yet */ ~rechecks();
        //bool hasPoison(const char *taint);
        eFileKind getFiletype(const char *tstr);
    
    protected:
        regex_t /*rePoison, */reIfiles, rePfiles;
        int m_nErrors;

};

class rechecksEx : public rechecks 
{
public:
	rechecksEx();
	~rechecksEx();
	bool IsInWhitelist(const char*);
	inline bool IsRegexOk() { return m_nErrors; };

protected:
	regex_t reWfiles;
};

#endif // _rechecks_h_
